# Preferences dialog, opens from Menu: File->Preferences

package Slic3r::GUI::Preferences;
use Wx qw(:dialog :id :misc :sizer :systemsettings wxTheApp);
use Wx::Event qw(EVT_BUTTON EVT_TEXT_ENTER);
use base 'Wx::Dialog';

sub new {
    my ($class, $parent) = @_;
    my $self = $class->SUPER::new($parent, -1, "Einstellungen", wxDefaultPosition, wxDefaultSize);
    $self->{values} = {};
    
    my $optgroup;
    $optgroup = Slic3r::GUI::OptionsGroup->new(
        parent  => $self,
        title   => 'Allgemein',
        on_change => sub {
            my ($opt_id) = @_;
            $self->{values}{$opt_id} = $optgroup->get_value($opt_id);
        },
        label_width => 280,
    );
#    $optgroup->append_single_option_line(Slic3r::GUI::OptionsGroup::Option->new(
#        opt_id      => 'version_check',
#        type        => 'bool',
#        label       => 'Check for updates',
#        tooltip     => 'If this is enabled, Slic3r will check for updates daily and display a reminder if a newer version is available.',
#        default     => $Slic3r::GUI::Settings->{_}{version_check} // 1,
#        readonly    => !wxTheApp->have_version_check,
#    ));
    $optgroup->append_single_option_line(Slic3r::GUI::OptionsGroup::Option->new(
        opt_id      => 'remember_output_path',
        type        => 'bool',
        label       => 'Ausgabeverzeichnis merken',
        tooltip     => 'Wenn angehakt wird Slic3r das zuletzt verwendete Ausgabeverzeichnis anbieten statt des Verzeichnis, in dem die verarbeiteten Dateien liegen.',
        default     => $Slic3r::GUI::Settings->{_}{remember_output_path},
    ));
    $optgroup->append_single_option_line(Slic3r::GUI::OptionsGroup::Option->new(
        opt_id      => 'autocenter',
        type        => 'bool',
        label       => 'Automatisches Zentrieren',
        tooltip     => 'Wenn angehakt wird Slic3r die Objekte zentrisch zum Druckbettmittelpunkt anordnen.',
        default     => $Slic3r::GUI::Settings->{_}{autocenter},
    ));
    $optgroup->append_single_option_line(Slic3r::GUI::OptionsGroup::Option->new(
        opt_id      => 'background_processing',
        type        => 'bool',
        label       => 'Hintergrundverarbeitung',
        tooltip     => 'Wenn angehakt wird Slic3r Objekte vorverarbeiten, sobald sie geladen worden sind, um die G-Code-Ausgabe zu beschleunigen.',
        default     => $Slic3r::GUI::Settings->{_}{background_processing},
        readonly    => !$Slic3r::have_threads,
    ));
    $optgroup->append_single_option_line(Slic3r::GUI::OptionsGroup::Option->new(
        opt_id      => 'no_controller',
        type        => 'bool',
        label       => 'USB/Seriell-Verbindung deaktivieren',
        tooltip     => 'Wenn angehakt wird keine Verbindungsaufnahme zum Drucker versucht. Das vereinfacht die Bedienoberflaeche falls kein Drucker angeschlossen ist.',
        default     => $Slic3r::GUI::Settings->{_}{no_controller},
    ));
    $optgroup->append_single_option_line(Slic3r::GUI::OptionsGroup::Option->new(
        opt_id      => 'no_defaults',
        type        => 'bool',
        label       => '"- default -" Voreinstellungen unterdruecken',
        tooltip     => 'Wenn angehakt gibt es keine "- default -" Voreinstellungen, sobald eine andere gueltige Voreinstellung vorhanden ist.',
        default     => $Slic3r::GUI::Settings->{_}{no_defaults},
    ));
    
    my $sizer = Wx::BoxSizer->new(wxVERTICAL);
    $sizer->Add($optgroup->sizer, 0, wxEXPAND | wxBOTTOM | wxLEFT | wxRIGHT, 10);
    
    my $buttons = $self->CreateStdDialogButtonSizer(wxOK | wxCANCEL);
    EVT_BUTTON($self, wxID_OK, sub { $self->_accept });
    $sizer->Add($buttons, 0, wxEXPAND | wxBOTTOM | wxLEFT | wxRIGHT, 10);
    
    $self->SetSizer($sizer);
    $sizer->SetSizeHints($self);
    
    return $self;
}

sub _accept {
    my $self = shift;
    
    if (defined($self->{values}{no_controller})) {
        Slic3r::GUI::warning_catcher($self)->("Slic3r muss neu gestartet werden, damit die Aenderungen wirksam werden koennen.");
    }
    
    $Slic3r::GUI::Settings->{_}{$_} = $self->{values}{$_} for keys %{$self->{values}};
    wxTheApp->save_settings;
    
    $self->EndModal(wxID_OK);
    $self->Close;  # needed on Linux

    # Nothify the UI to update itself from the ini file.
    wxTheApp->update_ui_from_settings;
}

1;
